function confmat = get_confusion_matrix(targets,outputs,flip)
%   Returns confusion matrix.
%   USAGE: 
%   confusion_matrix = get_confusion_matrix(targets,outputs)
%   confusion_matrix = get_confusion_matrix(targets,outputs,true)
%   targets - NxM matrix of true class labels. The target data are ground truth labels in 
%       1-of-N form (in each column, a single element is 1 to indicate the 
%       correct class, and all other elements are 0)
%   outputs - LxM matrix of class estimates.  The output data are the 
%       outputs from a neural network that performs classification. They can 
%       either be in 1-of-L form, or may also be probabilities where each column 
%       sums to 1.

    numClasses = size(outputs,1);
    if numClasses ~= 2 || nargin ~= 3
        flip = false;
    end
    % Unknown/dont-care targets
    known = find(isfinite(sum(targets,1)));
    targets = targets(:,known);
    outputs = outputs(:,known);
    numSamples = length(known);
    % Confusion matrix
    confmat = zeros(numClasses,numClasses);
    i = vec2ind(targets);
    j = vec2ind(outputs);
    for k=1:numSamples
        confmat(j(k),i(k)) = confmat(j(k),i(k)) + 1;
    end
    if flip
        temp = zeros(2,2);
        temp(1,1) = confmat(2,2);
        temp(2,2) = confmat(1,1);
        temp(1,2) = confmat(2,1);
        temp(2,1) = confmat(1,2);
        confmat = temp;
    end
end

